==> cost-interface-0.2.6-sources.jar: com/chinayanghe/tpm/cost/vo/out/CostBudgetAmtVo.java <==

package com.chinayanghe.tpm.cost.vo.out;

import java.io.Serializable;

/**
 * 预算年度、经销商、分公司、销售额（金额汇总）
 * @author arthur
 *
 */
public  class CostBudgetAmtVo  implements Serializable{
	
 
	/*预算年度**/
	private String budgetYear;
	/*经销商编码*/
	private String dealerCode;
	/*分公司名称**/
	private String subCompanyCode;
	/*销售额（金额汇总） 单位：分**/
	private Long totalAmt=0L;
	/*当前时间戳**/
	private Long currentTime;
	/*预留字段**/
	private String param0;
	private String param1;
	private int param2;
	public String getBudgetYear() {
		return budgetYear;
	}
	public void setBudgetYear(String budgetYear) {
		this.budgetYear = budgetYear;
	}
	public String getDealerCode() {
		return dealerCode;
	}
	public void setDealerCode(String dealerCode) {
		this.dealerCode = dealerCode;
	}
	public String getSubCompanyCode() {
		return subCompanyCode;
	}
	public void setSubCompanyCode(String subCompanyCode) {
		this.subCompanyCode = subCompanyCode;
	}
	public Long getTotalAmt() {
		return totalAmt;
	}
	public void setTotalAmt(Long totalAmt) {
		this.totalAmt = totalAmt;
	}
	public Long getCurrentTime() {
		return currentTime;
	}
	public void setCurrentTime(Long currentTime) {
		this.currentTime = currentTime;
	}
	public String getParam0() {
		return param0;
	}
	public void setParam0(String param0) {
		this.param0 = param0;
	}
	public String getParam1() {
		return param1;
	}
	public void setParam1(String param1) {
		this.param1 = param1;
	}
	public int getParam2() {
		return param2;
	}
	public void setParam2(int param2) {
		this.param2 = param2;
	}
	
	
}

==> cost-interface-0.3.13-sources.jar: com/chinayanghe/tpm/cost/vo/out/CostBudgetAmtVo.java <==

package com.chinayanghe.tpm.cost.vo.out;

import java.io.Serializable;

/**
 * 预算年度、经销商、分公司、销售额（金额汇总）
 * @author arthur
 *
 */
public  class CostBudgetAmtVo  implements Serializable{
	
 
	/*预算年度**/
	private String budgetYear;
	/*经销商编码*/
	private String dealerCode;
	/*分公司名称**/
	private String subCompanyCode;
	/*销售额（金额汇总） 单位：分**/
	private Long totalAmt=0L;
	/*当前时间戳**/
	private Long currentTime=System.currentTimeMillis();
	/*预留字段**/
	private String param0;
	private String param1;
	private int param2;
	public String getBudgetYear() {
		return budgetYear;
	}
	public void setBudgetYear(String budgetYear) {
		this.budgetYear = budgetYear;
	}
	public String getDealerCode() {
		return dealerCode;
	}
	public void setDealerCode(String dealerCode) {
		this.dealerCode = dealerCode;
	}
	public String getSubCompanyCode() {
		return subCompanyCode;
	}
	public void setSubCompanyCode(String subCompanyCode) {
		this.subCompanyCode = subCompanyCode;
	}
	public Long getTotalAmt() {
		return totalAmt;
	}
	public void setTotalAmt(Long totalAmt) {
		this.totalAmt = totalAmt;
	}
	public Long getCurrentTime() {
		return currentTime;
	}
	public void setCurrentTime(Long currentTime) {
		this.currentTime = currentTime;
	}
	public String getParam0() {
		return param0;
	}
	public void setParam0(String param0) {
		this.param0 = param0;
	}
	public String getParam1() {
		return param1;
	}
	public void setParam1(String param1) {
		this.param1 = param1;
	}
	public int getParam2() {
		return param2;
	}
	public void setParam2(int param2) {
		this.param2 = param2;
	}
	
	
}
